@@ -1,17 +1,16 @@
 #!/usr/bin/env python3
 
-# /// script
-# requires-python = ">=3.9"
-# ///
-
 import os
 import sys
 from datetime import datetime
+from pathlib import Path
 
 
 # Get command-line arguments
-file = sys.argv[1]
+page = Path(sys.argv[1])
+basename = sys.argv[2]
+file = Path(os.environ["NANCY_INPUT"]) / page.parent / basename
 
 time = os.stat(file).st_mtime
 dt = datetime.fromtimestamp(time)
-print(dt.strftime("%Y/%m/%d"))
+print(dt.strftime("%Y/%m/%d"), end="")
