@@ -5,25 +5,26 @@ Released under the GPL version 3, or (at your option) any later version.
 """
 
 import sys
-from typing import Callable, NoReturn, Optional, TextIO, Union
+from collections.abc import Callable
+from typing import NoReturn, TextIO
 from warnings import warn
 
 
 # Error messages
 def simple_warning(prog: str) -> Callable[..., None]:
     def _warning(
-        message: Union[Warning, str],
+        message: Warning | str,
         category: type[Warning],
         filename: str,
         lineno: int,
-        file: Optional[TextIO] = sys.stderr,
-        line: Optional[str] = None,
+        file: TextIO | None = sys.stderr,
+        line: str | None = None,
     ) -> None:
         print(f"{prog}: {message}", file=file or sys.stderr)
 
     return _warning
 
 
-def die(msg: str, code: Optional[int] = 1) -> NoReturn:
+def die(msg: str, code: int | None = 1) -> NoReturn:
     warn(msg)
     sys.exit(code)
