@@ -4,8 +4,8 @@ Copyright (c) Reuben Thomas 2024.
 Released under the GPL version 3, or (at your option) any later version.
 """
 
+from collections.abc import Callable
 from pathlib import Path
-from typing import Callable
 
 from pytest import CaptureFixture
 from testutils import Case, dir_test, make_tests
